# Simple client to control the MPRIS multimedia agent

This package contains a simple command-line utility that allows you to pair
and then control any computer with the MPRIS Linux desktop agent.

## Setup

### Server

Install the [MPRIS Linux desktop agent](https://github.com/Rudd-O/hassmpris_agent)
on the computer you want to control remotely.

### This package

Install this package on the computer you want to control other machines from.
You'll find the program `hassmpris-client` installed here.
